<!DOCTYPE html>
<html>

<head>
    <title>Gallery Index</title>
    <link rel="stylesheet" type="text/css" href="styles.css">
</head>

<body>
    <h1>Gallery Index</h1>
    {{ back_button|safe }}
    <!-- <a href="../index.html">Back to parent Index</a> -->
    <hr>
    </hr>
     
    <p align="right"> Created on - {{ timestamp }}</p>
    <p align="right">Created with boards version: {{ version }}</p>
    <hr>
    </hr>

    {{ index_links }}

    <hr>
    </hr>

    <!-- <h1 href="index.html">Gallery Index</h1> -->
</body>

</html>