@import url('https://fonts.googleapis.com/css2?family=Tagesschrift&display=swap');

.masonry-container {
    column-count: {{ col_count }};
    column-gap: {{ margin }}px;
    /* background-color: rgb(69, 69, 69); */
    margin-left: calc({{ margin }}px * 4);
    margin-right: calc({{ margin }}px * 4);
}
  
.masonry-item {
    display: inline-block;
    border: 2px solid hsl(0, 0%, 0%);
    width: 100%;
    margin-bottom: {{ margin }}px;  
}

.masonry-item video {
    width: 100%;
    height: auto;
    display: block;
}

.masonry-item img {
    width: 100%;
    display: block;
}

h1 {
    font-family: 'Tagesschrift', serif;
    color: rgb(128, 0, 128);
    text-align: center;
    margin-bottom: 40px;
    font-size: 2.5em;
}

.justified-container {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  gap: 6px;
  background-color: rgb(160, 160, 160);
  margin-left: 20px;
  margin-right: 20px;
}

.justified-item {
  border: 2px solid hsl(0, 0%, 0%);
  margin-bottom: 6px;
  flex-grow: 1;
  max-height: 240px;
  object-fit: cover;
  width: auto;
}

.justified-item img,
.justified-item video {
  height: 100%;
  width: auto;
  max-height: 240px;
  object-fit: contain;
  display: block;
}


/* button */

input[type="number"] {
  width: 10px;
  padding: 2px 12px;
  border: 2px solid #888;
  border-radius: 0px;
  font-size: 15px;
  color: #333;
  background-color: #f9f9f9;
  outline: none;
  transition: border-color 0.3s, box-shadow 0.3s;
  line-height: 0.8;
  height: 0.8;
  /* box-sizing: border-box; */
}

input[type="number"]:focus {
  border-color: #007BFF;
  box-shadow: 0 0 4px rgba(0, 123, 255, 0.5);
}

/* Remove spin buttons in Chrome/Edge */
input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  -webkit-appearance: none;
  margin: 0;
}

/* Remove spin buttons in Firefox */
input[type="number"] {
  -moz-appearance: textfield;
}


a {
  text-decoration: none;
  color: #000000;
}

a:hover {
  text-decoration: underline;
  color: #333;
}

/* a[href="index.html"] {
  display: block;
  margin: 20px auto;
  width: max-content;
  background: #fff;
  padding: 8px 16px;
  border-radius: 0px;
  box-shadow: 0 1px 4px rgba(0,0,0,0.1);
  } */
  
  /* a[href="index.html"] {
    display: block;
    margin: 20px auto;
    width: max-content;
    background: #fff;
    padding: 8px 16px;
    border-radius: 0px;
    box-shadow: 0 1px 4px rgba(0,0,0,0.1);
  } */

/* typography etc. e tc. */

h1 {
    font-family: 'Tagesschrift', serif;
    color: purple;
    text-align: center;
    margin-bottom: 40px;
    font-size: 2.5em;
}

body {
  background-color: rgb(179, 179, 179); 
  margin: 75;
  font-family: 'Tagesschrift', serif;
  color:rgb(0, 0, 0)
}

a {
  text-decoration: none;
  color: #000000;
}

a:hover {
  text-decoration: underline;
  color: #333;
}


/* .pagination {
    text-align: center;
    margin-top: 20px;
}
.pagination a {
    display: inline-block;
    padding: 6px 12px;
    margin: 0 4px;
    text-decoration: none;
    background-color: #eee;
    color: #333;
    border-radius: 4px;
}
.pagination a.active {
    font-weight: bold;
    background-color: #666;
    color: white;
} */

.pagination {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    gap: 8px 6px;
    margin: 20px calc({{ margin }}px * 4)px 0 calc({{ margin }}px * 4)px;
}

.pagination a , .pagination  input[type="submit"]{
    display: inline-block;
    padding: 6px 12px;
    text-decoration: none;
    background-color: #eee;
    color: #333;
    border-radius: 4px;
}

.pagination a:hover ,  input[type="submit"]:hover{
    background-color: #ccc;
}

.pagination strong {
    display: inline-block;
    padding: 6px 12px;
    background-color: #666;
    color: white;
    border-radius: 4px;
    font-weight: bold;
}